--[[
	OrderHallIcon, replace the OrderHallDemandBar
	Siweia
]]
local LE_GARRISON_TYPE_7_0 = Enum.GarrisonType.Type_7_0
local LE_FOLLOWER_TYPE_GARRISON_7_0 = Enum.GarrisonFollowerType.FollowerType_7_0

-- Configure
local DefaultPoint = {"TOP", 0, -20}

-- Class and Colors
local MyClass = select(2, UnitClass("player"))
local cc = RAID_CLASS_COLORS[MyClass]
local MyColor = format("|cff%02x%02x%02x", cc.r*255, cc.g*255, cc.b*255)

-- Style
local hall = CreateFrame("Frame", "OrderHallIcon", UIParent)
hall:SetSize(50, 50)
hall:SetPoint(unpack(DefaultPoint))
hall:SetMovable(true)
hall:SetUserPlaced(true)
hall:SetClampedToScreen(true)
hall:SetScript("OnMouseDown", function(self) self:StartMoving() end)
hall:SetScript("OnMouseUp", function(self) self:StopMovingOrSizing() end)

hall.Icon = hall:CreateTexture(nil, "ARTWORK")
hall.Icon:SetAllPoints()
hall.Icon:SetTexture("Interface\\TargetingFrame\\UI-Classes-Circles")
hall.Icon:SetTexCoord(unpack(CLASS_ICON_TCOORDS[strupper(MyClass)]))
hall.Category = {}

-- Function
local function RetrieveData(self)
	C_Garrison.RequestClassSpecCategoryInfo(LE_FOLLOWER_TYPE_GARRISON_7_0)

	local currency = C_Garrison.GetCurrencyTypes(LE_GARRISON_TYPE_7_0)
	local info = C_CurrencyInfo.GetCurrencyInfo(currency)
	self.name = info.name
	self.amount = info.quantity
	self.texture = info.iconFileID

	local categoryInfo = C_Garrison.GetClassSpecCategoryInfo(LE_FOLLOWER_TYPE_GARRISON_7_0)
	for index, info in ipairs(categoryInfo) do
		local category = self.Category
		if not category[index] then category[index] = {} end
		category[index].name = info.name
		category[index].count = info.count
		category[index].limit = info.limit
		category[index].description = info.description
		category[index].icon = info.icon
	end
	self.numCategory = #categoryInfo
end

-- Event
hall:RegisterUnitEvent("UNIT_AURA", "player")
hall:RegisterEvent("PLAYER_ENTERING_WORLD")
hall:RegisterEvent("ADDON_LOADED")
hall:SetScript("OnEvent", function(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == "Blizzard_OrderHallUI" then
		OrderHallCommandBar:Hide()
		OrderHallCommandBar.Show = function() return end
		self:UnregisterEvent("ADDON_LOADED")
	elseif event == "UNIT_AURA" or event == "PLAYER_ENTERING_WORLD" then
		local inOrderHall = C_Garrison.IsPlayerInGarrison(LE_GARRISON_TYPE_7_0)
		self:SetShown(inOrderHall)
	elseif event == "MODIFIER_STATE_CHANGED" and arg1 == "LSHIFT" then
		self:GetScript("OnEnter")(self)
	end
end)

local function getIconString(texture)
	return format("|T%s:12:12:0:0:64:64:5:59:5:59|t ", texture)
end

hall:SetScript("OnEnter", function(self)
	RetrieveData(self)

	GameTooltip:SetOwner(self, "ANCHOR_BOTTOMRIGHT");
	GameTooltip:ClearAllPoints()
	GameTooltip:SetPoint("TOPLEFT", self, "BOTTOMRIGHT", 5, -5)
	GameTooltip:ClearLines()
	GameTooltip:AddLine(MyColor.._G["ORDER_HALL_"..MyClass])
	GameTooltip:AddLine(" ")
	GameTooltip:AddDoubleLine(getIconString(self.texture)..self.name, self.amount, 1,1,1, 1,1,1)

	local blank
	for i = 1, self.numCategory do
		if not blank then
			GameTooltip:AddLine(" ")
			blank = true
		end
		local category = self.Category[i]
		if category then
			GameTooltip:AddDoubleLine(getIconString(category.icon)..category.name, category.count.."/"..category.limit, 1,1,1, 1,1,1)
			if IsShiftKeyDown() then
				GameTooltip:AddLine(category.description, .6,.8,1, 1)
			end
		end
	end
	GameTooltip:AddDoubleLine(" ", "--------------", 1,1,1, .6,.8,1)
	GameTooltip:AddDoubleLine(" ", "Hold <SHIFT> for Details", 1,1,1, .6,.8,1)
	GameTooltip:Show()

	self:RegisterEvent("MODIFIER_STATE_CHANGED")
end)

hall:SetScript("OnLeave", function(self)
	GameTooltip:Hide()
	self:UnregisterEvent("MODIFIER_STATE_CHANGED")
end)